@@ -1,6 +1,6 @@
 #! /usr/bin/perl -w
 
-# $Id: Ddl.pl,v 1.11 2001/03/20 01:49:51 rvsutherland Exp $
+# $Id: Ddl.pl,v 1.13 2001/04/28 13:50:25 rvsutherland Exp $
 
 use strict;
 
@@ -45,7 +45,12 @@ die "\nYou must specify an Owner.\n" unless $owner;
 
 print STDERR "Enter Name           : ";
 chomp( my $name = <STDIN> );
-die "\nYou must specify an object.\n" unless $name;
+die "\nYou must specify an object.\n"
+   unless (
+                $name
+             or "\U$type" eq 'COMPONENTS'
+             or "\U$type" eq 'SCHEMA'
+          );
 
 print STDERR "\n";
 
